@@ -3,4 +3,4 @@ rm -f dist/*.*
 python setup.py bdist_wheel sdist
 twine check dist/*
 python setup.py check -r -s
-# twine upload dist/* 
\ No newline at end of file
+twine upload dist/*
\ No newline at end of file
